@@ -1,6 +1,6 @@
 package RPC::Serialized::Server;
 {
-  $RPC::Serialized::Server::VERSION = '1.112530';
+  $RPC::Serialized::Server::VERSION = '1.123630';
 }
 
 use strict;
@@ -17,7 +17,7 @@ __PACKAGE__->mk_ro_accessors(qw/
     timeout
 /);
 __PACKAGE__->mk_accessors(qw/
-    trace handler_namespaces args_suppress_log
+    trace handler_namespaces args_suppress_log callbacks
 /);
 
 sub new {
@@ -47,6 +47,8 @@ sub new {
     $self->{HANDLER} = $params->rpc_serialized->{handlers}
         if exists $params->rpc_serialized->{handlers};
     $self->{AUTHZ_HANDLER} = RPC::Serialized::AuthzHandler->new;
+    $self->{CALLBACKS} = $params->rpc_serialized->{callbacks}
+        if exists $params->rpc_serialized->{callbacks};
 
     return $self;
 }
@@ -177,6 +179,20 @@ sub dispatch {
     $self->authorize( $call, $hc->target(@$args) )
         or throw_authz "Permission denied";
 
+    if ($self->callbacks->{pre_handler_argument_filter}) {
+        eval {
+            $args = [ $self->callbacks->{pre_handler_argument_filter}->(
+                { call => $call, server => $self },
+                @$args) ];
+        };
+        if ($@) {
+            throw_app sprintf("Callback '%s' for call '%s' returned %s"
+              ,  'pre_handler_argument_filter'
+              ,  $call
+              ,  $@);
+        }
+    }
+    
     return { RESPONSE => $hc->invoke(@$args) };
 }
 
